@@ -9,8 +9,7 @@ use 5.010;
 use Carp;
 
 use Getopt::Euclid qw( :vars<opt_> );
-use List::MoreUtils qw{firstidx} ;
-use version ; our $VERSION = qv('1.0.5');
+use version ; our $VERSION = qv('1.0.2');
 
 use VSGDR::UnitTest::TestSet::Test;
 use VSGDR::UnitTest::TestSet::Test::TestCondition;
@@ -21,7 +20,7 @@ use VSGDR::UnitTest::TestSet::Resx;
 use Data::Dumper;
 
 use IO::File ;
-#use Smart::Comments;
+use Smart::Comments;
 use File::Basename;
 
 my %ValidParserMakeArgs = ( vb  => "NET::VB"
@@ -29,10 +28,6 @@ my %ValidParserMakeArgs = ( vb  => "NET::VB"
                           , xls => "XLS"
                           , xml => "XML"
                           ) ;
-my %ValidParserMakeArgs2 = ( vb  => "NET2::VB"
-                           , cs  => "NET2::CS"
-                           ) ;                          
-                          
 #my @validSuffixes       = keys %ValidParserMakeArgs ;
 my @validSuffixes       = map { '.'.$_ } keys %ValidParserMakeArgs ;
 
@@ -42,7 +37,6 @@ my $infile;
 $infile = $opt_infile;
 
 my($infname, $directories, $insfx)      = fileparse($infile , @validSuffixes);
-croak 'Invalid input file'   unless defined $insfx ;
 $insfx        = lc $insfx ;
 $insfx        = substr $insfx,1;
 #warn Dumper $insfx;
@@ -52,12 +46,8 @@ die 'Invalid input file'  unless exists $ValidParserMakeArgs{$insfx} ;
 
 ### Build parsers
 
-my %Parsers            = () ;
-$Parsers{${insfx}}     = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${insfx}} } );
-# if input is in a .net language, add in a .net2 parser to the list
-if ( firstidx { $_ eq ${insfx} } ['cs','vb']  != -1 ) {
-    $Parsers{"${insfx}2"}  = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs2{${insfx}} } );
-}
+my %Parsers = () ;
+$Parsers{${insfx}}  = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${insfx}} } );
 
 ### Deserialise tests 
 my $testSet         = $Parsers{$insfx}->deserialise($infile );
@@ -78,7 +68,7 @@ foreach my $test_action ( sort keys %{$rh_testScripts} ) { ### Dump test action
     my $fh   = IO::File->new("> ${file}") ;
 
     if (defined ${fh} ) {
-        print {${fh}} $rh_testScripts->{$test_action} ;
+        print ${fh} $rh_testScripts->{$test_action} ;
         $fh->close;
     }
     else {
@@ -106,7 +96,7 @@ dumpGDRSql.pl - Dump Out the SQL for the Tests in a GDR Unit Test file.
 
 =head1 VERSION
 
-1.0.5
+1.0.2
 
 
 
